@@ -57,6 +57,7 @@ my @cpp_rename = (
 "debug/unordered_set:unordset",
 "debug/safe_unordered_base.h:safe_unordered_base.h01",
 "debug/safe_unordered_container.h:safe_unordered_container.h02",
+"debug/forward_list:forward.lis",
 
 "djgpp/bits/c++allocator.h:cxxallocator.h",
 "djgpp/bits/c++config.h:cxxconfig.h",
@@ -109,6 +110,7 @@ my @cpp_rename = (
 "profile/impl/profiler_vector_to_list.h:_profvtl.h1",
 "profile/unordered_map:_unordmap",
 "profile/unordered_set:_unordset",
+"profile/forward_list:forward.lis",
 
 "tr1/unordered_map.h:_unordmap.h1",
 "tr1/unordered_set.h:_unordset.h1",
@@ -116,10 +118,27 @@ my @cpp_rename = (
 "tr1/unordered_set:unordset",
 "tr1/hashtable_policy.h:hashtable_policy.h1",
 
+"tr2/dynamic_bitset.tcc:dynmbset.tcc",
+"tr2/dynamic_bitset:dynamic.bst",
+
 "unordered_map:unordmap",
 "unordered_set:unordset",
 "unordered_map:unordmap",
-"unordered_set:unordset"
+"unordered_set:unordset",
+"initializer_list:initiali.lst",
+"system_error:system.err",
+"condition_variable:conditio.var",
+"forward_list:forward.lis",
+"scoped_allocator:scoped.all",
+"shared_mutex:shared.mutr",
+
+"experimental/unordered_map:unordmap",
+"experimental/unordered_set:unordset",
+"experimental/forward_list:forward.list",
+"experimental/memory_resource:memory.res",
+"experimental/propagate_const:propagat.con",
+"experimental/string_view:string.vie",
+"experimental/system_error:system.err"
 );
 
 my @c_inc_rename = (
@@ -133,6 +152,7 @@ my @rename_list = (
 "lib/libsupc++.la:##/libsupcxx.la",
 "lib/libsupc++.a:##/libsupcxx.a",
 "lib/libstdcxx.a-gdb.py:##/libstdcxx_a-gdb-py",
+"lib/libstdc++fs.a:##/libstdcfs.a",
 "bin/g++.exe:##/gpp.exe",
 "bin/c++.exe:",
 "bin/djgpp-g++.exe:",
@@ -399,8 +419,10 @@ sub c_inc_rename_proc
         my $dir_name = dirname($orig_path);
         my $orig_name = basename($orig_path);
 
-        my $n1 = "$c_inc_dir/$dir_name/$orig_name";
-        my $n2 = "$c_inc_dir/$dir_name/$new_name";
+        $dir_name = $dir_name eq "." ? "" : "$dir_name/";
+
+        my $n1 = "$c_inc_dir/$dir_name$orig_name";
+        my $n2 = "$c_inc_dir/$dir_name$new_name";
 
         if ( -f $n1 )
         {
@@ -425,7 +447,7 @@ sub c_inc_rename_proc
         if (! /^djgpp\//)
         {
             $header_gcc{"header.gcc"} = $header_gcc{"header.gcc"} .
-                "$d2/$orig_name $d2/$new_name\n";
+                "$d2$orig_name $d2$new_name\n";
             #print "Write: $d2/$orig_name $d2/$new_name >>header.gcc\n";
         }
         do
@@ -557,18 +579,26 @@ sub getdjver
     }
     close $fd;
 
-    if ($major eq "2" && (($minor eq "3") || ($minor eq "4"))) 
+    if ($major eq "2" && ($minor ge "3")) 
     {
         if ($minor == 3)
         {
+            # Not actually supported: left in however
             $djver_desc = "2.03 Patchlevel 2";
             $djreq = $djver_desc;
         }
-        else
+        elsif ($minor == 4)
         {
+            # Also obsolete: left in howev er
             $djver_desc = "2.04 Beta 1 or above";
             $djreq = ">= 2.04 Beta 1";
         }
+        elsif ($minor > 5)
+        {
+            # Fix for DJGPP v2.1X later (perhaps not very soon)
+            $djver_dec = "2.0$minor";
+            $djreq = ">=2.0$minor";
+        }
         return sprintf("%d.%02d", $major, $minor);
     }
     return "";
@@ -679,6 +709,7 @@ sub mk_manifest
     my @cxxfiles = (
         'bin/gpp\.exe', '^include/cxx/', '/cc1plus\.exe',
         '/libstdcxx', '/libsupcxx', 'manifest/gpp',
+        '/libstdcfs.a',
         '/cat1/gpp', '/cp/news'
     );
 
@@ -698,11 +729,11 @@ sub mk_manifest
 
     my @gccfiles = (
         'bin/gcc\.exe', 'bin/cpp\.exe', 'bin/gcov\.exe', 'bin/gccbug',
-        'bin/gcc-(?:ar|nm|ranlib)\.exe', 'bin/gcov-tool\.exe',
+        'bin/gcc-(?:ar|nm|ranlib)\.exe', 'bin/gcov-tool\.exe', 'bin/gcov-dump\.exe',
         'include/ssp/', 'info/(?:cpp|gcc|libquadmath)', '/djgpp\.ver$',
         '/include/(?:am|bm|em|m|nm|pm|sm|tm|xm)mintrin',
         '/include/(?:cpuid|float|iso646|mm_malloc|mm3dnow|mmintcommon)\.h$',
-        '/include/(?:avx|imm|wmm|x86|bmi|tbm)intrin\.h$',
+        '/include/(?:avx|imm|wmm|x86|bmi|tbm|pku|clzero)intrin\.h$',
         '/include/(?:avx2|bmi2|f16c|fma|lzcnt)intrin.\h$',
         '/include/std(?:align|noreturn)\.h$',
         '/include/quadmath(?:|_weak).h',
@@ -710,7 +741,7 @@ sub mk_manifest
         '/include/header.gcc$',
         '/include-fixed/(?:limits|syslimits|wchar)\.h$',
         '/include-fixed/readme$',
-        '/include/(?:abm|fma4|ia32|lwp|popcnt|xop|xtest)intrin.h$',
+        '/include/(?:abm|fma4|ia32|lwp|popcnt|xop|xtest|mwaitx)intrin.h$',
 	'/include/(?:adx|fxsr|prfchw|rdseed|rtm|xsave|xsaveopt)intrin.h$',
         '/include/(?:clflushopt|clwb|pcommit|xsavec|xsaves|)intrin.(?:h|h2|h3)$',
         '/include/cross-stdarg.h$',
